# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from .privilege import (
    PrivilegeResource,
    AsyncPrivilegeResource,
    PrivilegeResourceWithRawResponse,
    AsyncPrivilegeResourceWithRawResponse,
    PrivilegeResourceWithStreamingResponse,
    AsyncPrivilegeResourceWithStreamingResponse,
)

__all__ = [
    "V1Resource",
    "AsyncV1Resource",
    "V1ResourceWithRawResponse",
    "AsyncV1ResourceWithRawResponse",
    "V1ResourceWithStreamingResponse",
    "AsyncV1ResourceWithStreamingResponse",
    "PrivilegeResource",
    "AsyncPrivilegeResource",
    "PrivilegeResourceWithRawResponse",
    "AsyncPrivilegeResourceWithRawResponse",
    "PrivilegeResourceWithStreamingResponse",
    "AsyncPrivilegeResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from casedev import Casedev, AsyncCasedev
from tests.utils import assert_matches_type
from casedev.types.compute import V1GetUsageResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestV1:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_get_pricing(self, client: Casedev) -> None:
        v1 = client.compute.v1.get_pricing()
        assert v1 is None

    @parametrize
    def test_raw_response_get_pricing(self, client: Casedev) -> None:
        response = client.compute.v1.with_raw_response.get_pricing()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert v1 is None

    @parametrize
    def test_streaming_response_get_pricing(self, client: Casedev) -> None:
        with client.compute.v1.with_streaming_response.get_pricing() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert v1 is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_get_usage(self, client: Casedev) -> None:
        v1 = client.compute.v1.get_usage()
        assert_matches_type(V1GetUsageResponse, v1, path=["response"])

    @parametrize
    def test_method_get_usage_with_all_params(self, client: Casedev) -> None:
        v1 = client.compute.v1.get_usage(
            month=3,
            year=2024,
        )
        assert_matches_type(V1GetUsageResponse, v1, path=["response"])

    @parametrize
    def test_raw_response_get_usage(self, client: Casedev) -> None:
        response = client.compute.v1.with_raw_response.get_usage()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1GetUsageResponse, v1, path=["response"])

    @parametrize
    def test_streaming_response_get_usage(self, client: Casedev) -> None:
        with client.compute.v1.with_streaming_response.get_usage() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1GetUsageResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncV1:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_get_pricing(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.compute.v1.get_pricing()
        assert v1 is None

    @parametrize
    async def test_raw_response_get_pricing(self, async_client: AsyncCasedev) -> None:
        response = await async_client.compute.v1.with_raw_response.get_pricing()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert v1 is None

    @parametrize
    async def test_streaming_response_get_pricing(self, async_client: AsyncCasedev) -> None:
        async with async_client.compute.v1.with_streaming_response.get_pricing() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert v1 is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_get_usage(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.compute.v1.get_usage()
        assert_matches_type(V1GetUsageResponse, v1, path=["response"])

    @parametrize
    async def test_method_get_usage_with_all_params(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.compute.v1.get_usage(
            month=3,
            year=2024,
        )
        assert_matches_type(V1GetUsageResponse, v1, path=["response"])

    @parametrize
    async def test_raw_response_get_usage(self, async_client: AsyncCasedev) -> None:
        response = await async_client.compute.v1.with_raw_response.get_usage()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1GetUsageResponse, v1, path=["response"])

    @parametrize
    async def test_streaming_response_get_usage(self, async_client: AsyncCasedev) -> None:
        async with async_client.compute.v1.with_streaming_response.get_usage() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1GetUsageResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True
